tst

    The output of tst is a report of the tests executed. The
    default format is a cli report containing the names of the
    test suites collected, one line per subject with the
    summaries of the tests executed, the total number of tests
    executed and the total time.

options

--verbose, -V           increase verbosity level
--timeout, -T           maximum time to run any test
--test-sources, -t      specify test-source files
--output-format, -f     choose report format: cli, 
--passed, -P            suppress subjects that don't pass all tests
--failed, -F            suppress subjects that pass any tests

--format, -f {default, json}

  default: the default output format (one subject + tests
  summaries of each test suite per line); json: json format;


